==> apache-iotdb-0.11.3-source-release.zip: apache-iotdb-0.11.3/tsfile/src/main/java/org/apache/iotdb/tsfile/read/reader/BatchDataIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.tsfile.read.reader;

import org.apache.iotdb.tsfile.read.TimeValuePair;
import org.apache.iotdb.tsfile.read.common.BatchData;

import java.io.IOException;

public class BatchDataIterator implements IPointReader {

  private BatchData batchData;

  public BatchDataIterator(BatchData batchData) {
    this.batchData = batchData;
  }

  @Override
  public boolean hasNextTimeValuePair() {
    return batchData.hasCurrent();
  }

  @Override
  public TimeValuePair nextTimeValuePair() {
    TimeValuePair timeValuePair = new TimeValuePair(batchData.currentTime(), batchData.currentTsPrimitiveType());
    batchData.next();
    return timeValuePair;
  }

  @Override
  public TimeValuePair currentTimeValuePair() {
    return new TimeValuePair(batchData.currentTime(), batchData.currentTsPrimitiveType());
  }

  @Override
  public void close() throws IOException {
    batchData = null;
  }
}

==> apache-iotdb-0.12.1-source-release.zip: apache-iotdb-0.12.1/tsfile/src/main/java/org/apache/iotdb/tsfile/read/reader/BatchDataIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.tsfile.read.reader;

import org.apache.iotdb.tsfile.read.TimeValuePair;
import org.apache.iotdb.tsfile.read.common.BatchData;

public class BatchDataIterator implements IPointReader {

  private BatchData batchData;

  public BatchDataIterator(BatchData batchData) {
    this.batchData = batchData;
  }

  @Override
  public boolean hasNextTimeValuePair() {
    return batchData.hasCurrent();
  }

  @Override
  public TimeValuePair nextTimeValuePair() {
    TimeValuePair timeValuePair =
        new TimeValuePair(batchData.currentTime(), batchData.currentTsPrimitiveType());
    batchData.next();
    return timeValuePair;
  }

  @Override
  public TimeValuePair currentTimeValuePair() {
    return new TimeValuePair(batchData.currentTime(), batchData.currentTsPrimitiveType());
  }

  @Override
  public void close() {
    batchData = null;
  }
}
